fgclustering package
====================

Submodules
----------

fgclustering.forest\_guided\_clustering module
----------------------------------------------

.. automodule:: fgclustering.forest_guided_clustering
   :members:
   :undoc-members:
   :show-inheritance:

fgclustering.optimizer module
-----------------------------

.. automodule:: fgclustering.optimizer
   :members:
   :undoc-members:
   :show-inheritance:

fgclustering.plotting module
----------------------------

.. automodule:: fgclustering.plotting
   :members:
   :undoc-members:
   :show-inheritance:

fgclustering.statistics module
------------------------------

.. automodule:: fgclustering.statistics
   :members:
   :undoc-members:
   :show-inheritance:

fgclustering.utils module
-------------------------

.. automodule:: fgclustering.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fgclustering
   :members:
   :undoc-members:
   :show-inheritance:
